'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = video;

var _video = require('../actions/video');

var _player = require('../actions/player');

var initialState = {
  currentSrc: null,
  duration: 0,
  currentTime: 0,
  seekingTime: 0,
  buffered: null,
  waiting: true,
  seeking: false,
  paused: true,
  autoPaused: false,
  ended: false,
  playbackRate: 1,
  muted: false,
  volume: 1,
  readyState: 0,
  networkState: 0,
  videoWidth: 0,
  videoHeight: 0,
  hasStarted: false,
  userActivity: true,
  isActive: false,
  isFullscreen: false
};

function video() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case _video.VOLUME_MUTE:
      return _extends({}, state, {
        muted: action.muted
      });
    case _video.LOAD_START:
      return _extends({}, state, {
        hasStarted: false,
        ended: false,
        buffered: action.buffered
      });
    case _video.CAN_PLAY:
      return _extends({}, state, {
        waiting: false,
        videoWidth: action.videoWidth,
        videoHeight: action.videoHeight,
        duration: action.duration,
        currentSrc: action.currentSrc,
        muted: action.muted
      });
    case _video.WAITING:
      return _extends({}, state, {
        waiting: true
      });
    case _video.CAN_PLAY_THROUGH:
    case _video.PLAYING:
      return _extends({}, state, {
        waiting: false
      });
    case _video.PLAY:
      return _extends({}, state, {
        ended: false,
        paused: false,
        autoPaused: false,
        waiting: false,
        hasStarted: true,
        duration: action.duration,
        currentSrc: action.currentSrc,
        muted: action.muted
      });
    case _video.PAUSE:
      return _extends({}, state, {
        paused: true
      });
    case _video.END:
      return _extends({}, state, {
        ended: true
      });
    case _video.SEEKING:
      return _extends({}, state, {
        seeking: true
      });
    case _video.SEEKED:
      return _extends({}, state, {
        seeking: false
      });
    case _video.SEEKING_TIME:
      return _extends({}, state, {
        seekingTime: action.time
      });
    case _video.END_SEEKING:
      return _extends({}, state, {
        seekingTime: 0,
        currentTime: action.time
      });
    case _video.DURATION_CHANGE:
      return _extends({}, state, {
        duration: action.duration
      });
    case _video.TIME_UPDATE:
      return _extends({}, state, {
        currentTime: action.time
      });
    case _video.VOLUME_CHANGE:
      return _extends({}, state, {
        volume: action.volume,
        muted: action.muted
      });
    case _video.PROGRESS_CHANGE:
      return _extends({}, state, {
        buffered: action.buffered
      });
    case _video.RATE_CHANGE:
      return _extends({}, state, {
        playbackRate: action.rate
      });
    case _player.FULLSCREEN_CHANGE:
      return _extends({}, state, {
        isFullscreen: !!action.isFullscreen
      });
    case _player.USER_ACTIVATE:
      return _extends({}, state, {
        userActivity: action.activity
      });
    case _player.PLAYER_ACTIVATE:
      return _extends({}, state, {
        isActive: action.activity
      });
    default:
      return state;
  }
}